// =====================================================================================================================
// xm-chg-change-ap-detail-signature-ws.js
// Proxy / wrapper class for the corresponding Web service in Remedy
// =====================================================================================================================
var XMCHGChangeAPDetailSignatureWS = BaseClass.extend({

    LOG_SOURCE: "xm-chg-change-ap-detail-signature-ws.js: ",
    XM_CHG_CHANGE_AP_DETAIL_SIGNATURE_WSDL_DEFN: "integrationservices/bmcremedy/bmcremedychange/soap/XM-CHG-ChangeAPDetailSignature-WS-soapui-project.xml",
    XM_CHG_CHANGE_AP_DETAIL_SIGNATURE_SOAP_VERSION: "1_1",

    /**
     * Initialize the class variables
     * @param wsutil instance of the WSUtil class for making the webservice calls
     * @param endpoint URL of the webservice endpoint
     */
    init: function(wsutil, endpoint)
    {
        this.log = new Logger(this.LOG_SOURCE);
        this.wsutil = wsutil;
        this.endpoint = endpoint;

        log.debug("XMCHGChangeAPDetailSignatureWS() - XM_CHG_CHANGE_AP_DETAIL_SIGNATURE_WSDL_DEFN [" + this.XM_CHG_CHANGE_AP_DETAIL_SIGNATURE_WSDL_DEFN + "]");
    },

    /**
     * Send the Approval response received from the xmatters responder
     *
     * @param username name of the user making the request
     * @param password string repesenting the user password
     * @param approval instance representing the approval status
     */
    setApprovalStatus: function(username, password, approval)
    {
	    this.log.debug("Enter - setApprovalStatus");

	    var msg = new SOAPMessage(this.XM_CHG_CHANGE_AP_DETAIL_SIGNATURE_WSDL_DEFN, "SetApprovalStatus", "SetApprovalStatus", this.XM_CHG_CHANGE_AP_DETAIL_SIGNATURE_SOAP_VERSION);

	    msg.setParameter("userName", username);
	    msg.setParameter("password", password);

	    msg.setParameter("Approval_Status2", approval.Approval_Status2);
	    msg.setParameter("Approver_Signature", getNonNullValue(approval.Approver_Signature));
	    msg.setParameter("Request_ID", getNonNullValue(approval.Request_ID));
	    
	    // Update the ChangeAPDetailSignature record with the Approval Status of the xmatters responder
	    this.wsutil.sendReceive(this.endpoint, msg);

	    this.log.debug("Exit - setApprovalStatus");
    },

  
    /**
     * Query for a list of approvals based on the qualification provided.
     *
     * @param username name of the user making the request
     * @param password string repesenting the user password
     * @param qualification The qualification to limit which approvals are returned
     *
     * @returns a list of approvals
     */
    getApprovals: function(username, password, qualification)
    {
        this.log.debug("Enter - getApprovals");

        this.log.debug("getApprovals [" + qualification + "]");

        if (qualification == null)
        {
            throw("getApprovals - qualification is null");
        }

        var msg = new SOAPMessage(this.XM_CHG_CHANGE_AP_DETAIL_SIGNATURE_WSDL_DEFN, "GetApprovals", "GetApprovals", this.XM_CHG_CHANGE_AP_DETAIL_SIGNATURE_SOAP_VERSION);

        msg.setParameter("userName", username);
        msg.setParameter("password", password);
        msg.setParameter("Qualification", qualification);

        // Retrieve the Change Request from Remedy and unmarshall it into a Javascript object with properties
        // corresponding to the XML body of the response.
        var response = this.wsutil.sendReceive(this.endpoint, msg);

        // The response from this function is an array of one or more "Approver" objects created by
        // unmarshalling the XML into the properties of an object
        var approvals = [];

        for each (var item in response.*::GetApprovalsResponse.*::getListValues)
        {
            var approval = this.wsutil.unmarshall(item, newRemedyObject());
            approvals.push(approval);
        }

        this.log.debug("Exit - getApprovals");
        return approvals;
    }

});
