// =====================================================================================================================
// xm-chg-change-interface-ws.js
// Proxy / wrapper class for the corresponding Web service in Remedy
// =====================================================================================================================
var XMCHGChangeInterfaceWS = BaseClass.extend({

  LOG_SOURCE: "xm-chg-change-interface-ws.js: ",
  XM_CHG_CHANGE_INTERFACE_WSDL_DEFN: "integrationservices/bmcremedy/bmcremedychange/soap/XM-CHG-ChangeInterface-WS-soapui-project.xml",
  XM_CHG_CHANGE_INTERFACE_SOAP_VERSION: "1_1",
  
  /**
   * Initialize the class variables
   * @param wsutil instance of the WSUtil class for making the webservice calls
   * @param endpoint URL of the webservice endpoint
   */
  init: function(wsutil, endpoint)
  {
    this.log = new Logger(this.LOG_SOURCE);
    this.wsutil = wsutil;
    this.endpoint = endpoint;

    log.debug("XMCHGChangeInterfaceWS() - XM_CHG_CHANGE_INTERFACE_WSDL_DEFN [" + this.XM_CHG_CHANGE_INTERFACE_WSDL_DEFN + "]");
  },

  /**
   * Add a worklog entry to the changeRequest in Remedy
   *
   * @param username name of the user making the request
   * @param password string repesenting the user password
   * @param changeRequest instance of the changeRequest to update
   */
  addWorkLog: function(username, password, changeRequest)
  {
    this.log.debug("Enter - addWorkLog");

    var msg = new SOAPMessage(this.XM_CHG_CHANGE_INTERFACE_WSDL_DEFN, "AddWorkLog", "AddWorkLog", this.XM_CHG_CHANGE_INTERFACE_SOAP_VERSION);

    msg.setParameter("userName", username);
    msg.setParameter("password", password);

    msg.setParameter("Action", changeRequest.Action);
    msg.setParameter("Work_Info_Summary", getNonNullValue(changeRequest.Work_Info_Summary).substring(0,WORK_INFO_SUMMARY_FIELD_LENGTH-1));
    msg.setParameter("Work_Info_Notes", getNonNullValue(changeRequest.Work_Info_Notes));
    msg.setParameter("Work_Info_Type", getNonNullValue(changeRequest.Work_Info_Type));
    msg.setParameter("Communication_Source", getNonNullValue(changeRequest.Communication_Source));
    msg.setParameter("Work_Info_Locked", getNonNullValue(changeRequest.Work_Info_Locked));
    msg.setParameter("Work_Info_View_Access", getNonNullValue(changeRequest.Work_Info_View_Access));
    msg.setParameter("Infrastructure_Change_ID", changeRequest.Infrastructure_Change_ID);
    
    // Update the changeRequest assignee in Remedy
    this.wsutil.sendReceive(this.endpoint, msg);

    this.log.debug("Exit - addWorkLog");
  }
});
