/**
 * =====================================================================================================================
 *
 * Proxy class that exposes the operations of the XM_CHG_InfrastructureChange_WS Web service hosted by Remedy Change.
 *
 * =====================================================================================================================
 */
var XMCHGInfrastructureChangeWS = BaseClass.extend({

  LOG_SOURCE: "xm-chg-infrastructure-change-ws.js: ",
  XM_CHG_INFRASTRUCTURE_CHANGE_WSDL_DEFN: "integrationservices/bmcremedy/bmcremedychange/soap/XM-CHG-InfrastructureChange-WS-soapui-project.xml",
  XM_CHG_INFRASTRUCTURE_CHANGE_SOAP_VERSION: "1_1",
  
  /**
   * Initialize the class variables
   * @param wsutil instance of the WSUtil class for making the webservice calls
   * @param endpoint URL of the webservice endpoint
   */
  init: function(wsutil, endpoint)
  {
    this.log = new Logger(this.LOG_SOURCE);
    this.wsutil = wsutil;
    this.endpoint = endpoint;
  },

  /**
   * Retrieves the Change Request information for the selected Change Request.
   * 
   * @param username name of the user making the request
   * @param password string repesenting the user password
   * @param changeRequestId unique identifier for the incident to search for
   * @return a Change Request object
   */
  getChangeRequest: function(username, password, changeRequestId)
  {
    this.log.debug("Enter - getChangeRequest");

    var msg = new SOAPMessage(this.XM_CHG_INFRASTRUCTURE_CHANGE_WSDL_DEFN, "GetChange", "GetChange", this.XM_CHG_INFRASTRUCTURE_CHANGE_SOAP_VERSION);

    msg.setParameter("userName", username);
    msg.setParameter("password", password);
    msg.setParameter("Infrastructure_Change_ID", changeRequestId);

    // Retrieve the Change Request from Remedy and unmarshall it into a Javascript object with properties
    // corresponding to the XML body of the response.
    var response = this.wsutil.sendReceive(this.endpoint, msg);
    var change = this.wsutil.unmarshall(response.*::GetChangeResponse, newRemedyObject());
    
    this.log.debug("Exit - getChangeRequest");
    return change;
  } 
});
